pub fn expand_orpc(args: OrpcArgs, func: ItemFn) -> TokenStreamExpand description
Generate the full expansion for #[rorpc::route(method, path)] or shorthand macros.
Returns the original function unchanged plus all inventory registrations.
pub fn expand_orpc(args: OrpcArgs, func: ItemFn) -> TokenStreamGenerate the full expansion for #[rorpc::route(method, path)] or shorthand macros.
Returns the original function unchanged plus all inventory registrations.