pub fn expand_orpc(args: OrpcArgs, func: ItemFn) -> TokenStreamExpand description
Generate the full expansion for #[orpc(method, path)] async fn handler(...).
Returns the original function unchanged plus all inventory registrations.
pub fn expand_orpc(args: OrpcArgs, func: ItemFn) -> TokenStreamGenerate the full expansion for #[orpc(method, path)] async fn handler(...).
Returns the original function unchanged plus all inventory registrations.